from django.contrib.auth import get_user_model


class WSFedBackend(object):
    """
    Create or update user based on ADFS WS-Fed response
    """

    def authenticate(self, user_info, **kwargs):
        """Check if user exists
        """
        UserModel = get_user_model()  # noqa
        user, created = UserModel._default_manager.update_or_create(
            email=user_info['email'], defaults=user_info)
        return user if self.user_can_authenticate(user) else None

    def user_can_authenticate(self, user):
        """
        Reject users with is_active=False. Custom user models that don't have
        that attribute are allowed.
        """
        is_active = getattr(user, 'is_active', None)
        return bool(is_active)

    def get_user(self, user_id):
        UserModel = get_user_model()  # noqa
        try:
            user = UserModel._default_manager.get(pk=user_id)
        except UserModel.DoesNotExist:
            return None
        return user if self.user_can_authenticate(user) else None
