from django.test import SimpleTestCase, RequestFactory

from contrib.adfsauth.ws_fed import WSFedAuthentication


class WSFedAuthenticationTest(SimpleTestCase):

    def setUp(self):
        request = RequestFactory().get("/wsignout/")
        self.obj = WSFedAuthentication(request, None)
        self.user_info = {
            'name': 'nome',
            'email': 'email',
            'photo': 'fotografia',
            'primary_phone': 'telemovel',
            'nic': 'nic'
        }

    def test_clean_user_info_no_email(self):
        # Check no email provider
        self.user_info.pop('email')
        self.assertEqual(self.obj.clean_user_info(self.user_info), None)

    def test_clean_user_info_valid_email(self):
        # Check email provided
        self.assertNotEqual(self.obj.clean_user_info(self.user_info), None)

    def test_clean_user_info_invalid_phone_number(self):
        # Check for invalid phone number
        self.assertEqual(
            self.obj.clean_user_info(self.user_info)['primary_phone'], '')

    def test_clean_user_info_valid_phone_number(self):
        # Check for valid phone number
        self.user_info['primary_phone'] = '+351912243452'
        self.assertEqual(
            self.obj.clean_user_info(self.user_info)['primary_phone'],
            '+351912243452')
