import logging

from django.conf import settings
from django.shortcuts import redirect, render
from django.views.generic import View
from django.views.decorators.csrf import csrf_exempt
from django.contrib.auth import logout
from django.utils.decorators import method_decorator

from .ws_fed import WSFedAuthentication, adfs_wsfed


logger = logging.getLogger('evote.contrib.adfsauth')


@method_decorator(csrf_exempt, name='dispatch')
class WSFedSigninView(View):
    """ Sign in view """

    template_name = "adfsauth/signin_fail.html"

    def get(self, request, *args, **kwargs):
        """ """
        return redirect(adfs_wsfed.get_signin_url())

    def post(self, request, *args, **kwargs):
        """ """
        config = getattr(settings, "ADFS_WSFED_CONFIG", {})
        post_response = config.get('post_response', 'wresult')
        response = request.POST.get(post_response, '')
        # log response from adfs server
        logger.info(response)
        wsfed_auth = WSFedAuthentication(request, response)
        is_authenticated = wsfed_auth.authenticate()
        if is_authenticated:
            return redirect(settings.LOGIN_REDIRECT_URL)
        # Authentication fail
        return render(request, config.get('template_fail', self.template_name))


class WSFedSignoutView(View):
    """ Sign out view """

    def get(self, request, *args, **kwargs):
        """ """
        logout(request)
        return redirect(adfs_wsfed.get_signout_url())
