import base64
import logging
import os.path
from datetime import datetime
from datetime import timedelta
from suds import WebFault

from django.core.files.base import ContentFile

from contrib.umws.umws_service import UMWebService

# Dummy data to simulate the response of WS of DTSI
dummy_data = {
    'username': 'dev@eurotux.com',
    'phone': '+351912233441',
    'name': 'Dev Test'
}


logger = logging.getLogger('evote.contrib.umws')


class MembersService(UMWebService):
    """ """
    settings_name = "MEMBERS_SERVICE_CONFIG"

    def is_email_valid(self, email):
        """ """
        if self.in_debug():
            return True
        client = self.get_client()
        return client.service.IsEmailValid(email)

    def get_contact_info_by_email(self, email):
        """ """
        if self.in_debug():
            if email == "unknown@eurotux.com":
                return {}
            return dummy_data
        client = self.get_client()
        logger.info("Get contact info by email: %s", email)
        contact = client.service.GetContactInfoByEmail(email)
        if contact:
            return self.get_data(contact)
        return {}

    def get_contact_info_by_login(self, login):
        """ """
        if self.in_debug():
            if login == "unknown":
                return {}
            return dummy_data
        client = self.get_client()
        logger.info("Get contact info by login: %s", login)
        contact = client.service.GetContactInfoByLogin(login)
        if contact:
            return self.get_data(contact)
        return {}

    def get_photo_by_login(self, login):
        """ Returns only the base64 string """
        if self.in_debug():
            return None
        client = self.get_client()
        try:
            photo = client.service.GetPhotoBase64ByLogin(login)
            logger.debug("Photo base64 string returned: %s", photo)
            if photo:
                logger.info("Photo base64 string returned (size): %s",
                            len(photo))
            return photo
        except WebFault:
            logger.exception("Photo base64 impossible to obtain")
        return None

    def get_data(self, contact):
        """ Contact Element has this fields:
            'DataAlteracao', 'Email', 'Login', 'Name', 'Number', 'OutroEmail'
            For now we only need: 'Email', 'Name', 'Number'
        """
        email = contact.Email
        num = contact.Number
        name = contact.Name
        data = {
            'username': '' if email is None else email.title().lower(),
            'phone': '' if num is None else num.title(),
            'name': '' if name is None else name.title(),
        }
        logger.info("Contact info returned: %s", data)
        return data

    def is_time_to_update_photo(self, photo, days=1):
        """ """
        if not photo:
            return True
        ts = os.path.getmtime(photo.path)
        next_update = datetime.utcfromtimestamp(ts) + timedelta(days=days)
        if next_update > datetime.now():
            return False
        return True

    @staticmethod
    def set_user_photo(sender, user, request, **kwargs):
        """Callback staticmethod for user_logged_in signal"""

        if members_service.is_time_to_update_photo(user.photo):
            login = members_service.upn_to_login(user.upn)
            photo_base64 = members_service.get_photo_by_login(login)
            if photo_base64 and login:
                file_name = login + ".png"  # FIXME
                user.photo.save(file_name,
                                ContentFile(base64.b64decode(photo_base64)),
                                False)
                user.save(update_fields=['photo'])


members_service = MembersService()
