from django.test import SimpleTestCase
from mock import patch
from members_service import dummy_data
from django.core.management import call_command
from contrib.umws.test_utils import ClientMock
from .members_service import members_service


class Contact(object):
    """ """
    Email = ""
    Name = ""
    Number = ""

    def __init__(self, Email, Name, Number):  # noqa
        self.Email = Email
        self.Name = Name
        self.Number = Number


class ValidationServiceClientMock(ClientMock):
    """
    Mock object that implements Validation Service
    """

    def IsEmailValid(self, email):  # noqa
        """ Check if email is valid
        """
        return True

    def GetContactInfoByEmail(self, email):  # noqa
        """ Get contact info by email
        """
        return Contact(Email="dev@eurotux.com",
                       Name="Dev test",
                       Number="+351912233441")

    def GetContactInfoByLogin(self, login):  # noqa
        """ Get contact info by login
        """
        return Contact(Email="dev@eurotux.com",
                       Name="Dev test",
                       Number="+351912233441")

    def GetPhotoBase64ByLogin(self, login):  # noqa
        """ Get photo by login
        """
        return "base64string"


class MembersServiceTestCase(SimpleTestCase):
    """ """

    def setUp(self):
        members_service.debug = False

    @patch('contrib.umws.members.members_service.get_client')
    def test_is_email_valid(self, get_client):
        """ """
        get_client.return_value = ValidationServiceClientMock("url_wsdl")
        valid = members_service.is_email_valid("")
        self.assertEqual(valid, True)

    @patch('contrib.umws.members.members_service.get_client')
    def test_get_contact_info_by_email(self, get_client):
        """ """
        get_client.return_value = ValidationServiceClientMock("url_wsdl")
        contact = members_service.get_contact_info_by_email("")
        self.assertEqual(contact, dummy_data)

    @patch('contrib.umws.members.members_service.get_client')
    def test_get_contact_info_by_login(self, get_client):
        """ """
        get_client.return_value = ValidationServiceClientMock("url_wsdl")
        contact = members_service.get_contact_info_by_login("")
        self.assertEqual(contact, dummy_data)

    @patch('contrib.umws.members.members_service.get_client')
    def test_get_photo_by_login(self, get_client):
        """ """
        get_client.return_value = ValidationServiceClientMock("url_wsdl")
        photo = members_service.get_photo_by_login("")
        self.assertEqual(photo, "base64string")

    def test_ping_command_fail(self):
        """ """
        with self.assertRaises(SystemExit) as cm:
            call_command('check_member_service')
        self.assertEqual(cm.exception.code, 1)

    @patch('contrib.umws.members.members_service.ping')
    def test_ping_command_ok(self, mock_fn):
        mock_fn.return_value = True
        """ """
        with self.assertRaises(SystemExit) as cm:
            call_command('check_member_service')
        self.assertEqual(cm.exception.code, 0)
