from __future__ import unicode_literals

import logging

from contrib.umws.umws_service import UMWebService


logger = logging.getLogger('evote.contrib.umws')


class SMSService(UMWebService):
    """ """
    settings_name = "SMS_SERVICE_CONFIG"

    def mask_number(self, number):
        """ Mask phone number to be used in logs.
            examples: '919999999' returns '91****999'
                      '+351919999999' returns '+35191****999'
                      '1234' returns '1234'
        """
        if not isinstance(number, basestring):
            number = str(number)
        if len(number) > 8:
            prefix = number[:len(number) - 7]
            sufix = number[len(number) - 3:]
            return "%s****%s" % (prefix, sufix)
        return number

    def send_message(self, number, message, anonymous=False):
        """ Returns message id (int) """
        if self.in_debug():
            return "Success Message"
        client = self.get_client()
        try:
            msg_id = client.service.SendMessage(number, message, anonymous)
        except:
            logger.critical(
                "Send SMS Failed: message '%s' to '%s'",
                message, self.mask_number(number), exc_info=True)
            raise
        else:
            logger.info("Sent SMS message '%s' to '%s' with id (%s)",
                        message, self.mask_number(number), msg_id)
        return msg_id

    def get_message_status(self, msgid):
        """ """
        if self.in_debug():
            return "sended"  # FIXME missing info
        client = self.get_client()
        status_msg = client.service.GetMessageStatus(msgid)
        return status_msg


sms_service = SMSService()
