from __future__ import absolute_import

import logging

from celery.loaders.base import BaseLoader
from celery import signals

from django import db


logger = logging.getLogger('celery.loader')


class EvoteLoader(BaseLoader):
    """The Evote loader."""

    def _install_signal_handlers(self):
        # Need to close any open database connection after
        # any embedded celerybeat process forks.
        signals.beat_embedded_init.connect(self.close_database)

    def close_database(self):
        """Close all db connection"""
        db.close_old_connections()
        logger.debug('Closed old database connections')

    def on_process_cleanup(self):
        """Called after a task is executed."""
        self.close_database()

    def on_task_init(self, task_id, task):
        """Called before a task is executed."""
        try:
            is_eager = task.request.is_eager
        except AttributeError:
            is_eager = False
        if not is_eager:
            self.close_database()

    def on_worker_init(self):
        """Called when the worker (celery worker) starts."""
        self.close_database()

    def on_worker_process_init(self):
        """Called when a child process starts."""
        self.close_database()
