from __future__ import unicode_literals

import os
import mimetypes

from django.core.urlresolvers import reverse_lazy

from evote.settings import *  # NOQA


# HACK: support serving svg images

mimetypes.add_type("image/svg+xml", ".svg", True)
mimetypes.add_type("image/svg+xml", ".svgz", True)


# Django settings

SITE_ID = 1

DEBUG = True
TEMPLATE_DEBUG = True
THUMBNAIL_DEBUG = True


DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.mysql',
        'NAME': os.environ.get('MYSQL_DATABASE'),
        'USER': os.environ.get('MYSQL_USER'),
        'PASSWORD': os.environ.get('MYSQL_PASSWORD'),
        'HOST': 'db',
        'PORT': '3306'
    }
}

CACHES = {
    "default": {
        "BACKEND": "django_redis.cache.RedisCache",
        "LOCATION": os.environ.get('REDIS_PORT'),
        "OPTIONS": {
            "CLIENT_CLASS": "django_redis.client.DefaultClient",
        }
    }
}


# Auth settings

LOGIN_REDIRECT_URL = reverse_lazy("voters:electoralprocess-list")
LOGIN_URL = reverse_lazy("voters:login")
LOGOUT_URL = reverse_lazy("voters:logout")
LOGIN_REDIRECT_URL = reverse_lazy("voters:electoralprocess-list")

AUTHENTICATION_BACKENDS += [  # NOQA
    'django.contrib.auth.backends.ModelBackend',  # this is default
]
SESSION_COOKIE_SECURE = False


# Celery settings

CELERY_BROKER_URL = 'amqp://{}:{}@rabbitmq//'.format(
    os.environ.get('RABBITMQ_DEFAULT_USER'),
    os.environ.get('RABBITMQ_DEFAULT_PASS'))
CELERY_EMAIL_BACKEND = 'django.core.mail.backends.console.EmailBackend'


# Sorl thumbnail settings

THUMBNAIL_KVSTORE = "sorl.thumbnail.kvstores.redis_kvstore.KVStore"
THUMBNAIL_DUMMY = True
THUMBNAIL_DEBUG = True


# debug toolbar settings

DEBUG_TOOLBAR_PATCH_SETTINGS = False
INSTALLED_APPS += (  # NOQA
    'debug_toolbar',
)
MIDDLEWARE += [  # NOQA
    'debug_toolbar.middleware.DebugToolbarMiddleware',
]
DEBUG_TOOLBAR_CONFIG = {
    "SHOW_TOOLBAR_CALLBACK": lambda x: True,
}

EVOTE_SERVICES_ENDPOINTS = {
    'anonymizer': 'http://{}/api/v1/'.format(os.environ.get("SN_EVOTE_AS")),
    'counter': 'http://{}/api/v1/'.format(os.environ.get("SN_EVOTE_CS"))
}
