from __future__ import unicode_literals

from django.views.decorators.http import last_modified
from django.conf.urls.i18n import i18n_patterns
from django.views.i18n import JavaScriptCatalog
from django.conf.urls import include, url
from django.utils import timezone
from django.conf import settings

from evotevotings.management.views import ManagementErrorView
from evotecore.ajax import PingView


last_modified_date = timezone.now()


urlpatterns = [
    url(
        regex=r'^i18n/',
        view=include('django.conf.urls.i18n')
    ),
    url(
        regex=r'^adfs/',
        view=include("contrib.adfsauth.urls")
    ),
    url(
        regex=r'^ama/',
        view=include('contrib.ama.urls')
    ),

    # ajax view
    url(
        regex=r'^ping/$',
        view=PingView.as_view(),
        name="ping"
    ),
]

urlpatterns += i18n_patterns(
    url(
        regex=r'^jsi18n/$',
        view=last_modified(lambda req, **kw: last_modified_date)(
            JavaScriptCatalog.as_view()),
        name="javascript-catalog"
    ),
    url(
        regex=r'^messages/',
        view=include("evotemessages.urls")
    ),
    url(
        regex=r'^',
        view=include('evotevotings.management.urls')
    )
)


handler400 = ManagementErrorView.get_view_rendered(400)
handler403 = ManagementErrorView.get_view_rendered(403)
handler404 = ManagementErrorView.get_view_rendered(404)
handler500 = ManagementErrorView.get_view_rendered(500)


if settings.DEBUG:
    import debug_toolbar

    from django.conf.urls.static import static
    from django.contrib.staticfiles.urls import staticfiles_urlpatterns

    urlpatterns += [
        url(
            regex=r'^__debug__/',
            view=include(debug_toolbar.urls)
        )
    ]
    # Serve static and media files from development server
    urlpatterns += staticfiles_urlpatterns()
    urlpatterns += static(settings.MEDIA_URL,
                          document_root=settings.MEDIA_ROOT)
