import itertools

from django.utils.html import format_html
from django.utils.formats import localize

import django_tables2 as tables
from sorl.thumbnail import get_thumbnail


class ImageColumn(tables.Column):
    """
    Custom Column of image
    """

    def render(self, value):
        if value:
            thumb = get_thumbnail(value, '78', crop='center', quality=99)
            if thumb:
                return format_html(u"<img src='{}' width='{}' height='{}'>",
                                   thumb.url, thumb.width, thumb.height)
        return ""


class DateTimeColumn(tables.Column):
    """
    Custom Column of Date Time field
    """

    def __init__(self, icon=True, icon_classes="alg-l", options=None, *args,
                 **kwargs):
        super(DateTimeColumn, self).__init__(*args, **kwargs)
        self.icon = icon
        self.icon_classes = icon_classes

    def render(self, value):
        icon = ""
        if self.icon:
            icon = "<i class='ev-icon evi-calendar " + self.icon_classes + \
                "'></i>"
        return format_html(icon + localize(value))


class CounterColumn(tables.Column):
    """
    Custom Column for line numbers
    """

    def render(self):
        self.row_counter = getattr(self, 'row_counter',
                                   itertools.count(start=1))
        return next(self.row_counter)
