# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.test import SimpleTestCase

from evotecore.utils import documents_upload_to, images_upload_to, compare_data


class UtilsCase(SimpleTestCase):
    """ """

    def test_documents_upload_to_path(self):
        path = documents_upload_to(None, "test.txt")
        self.assertIn("documents", path)
        self.assertIn("test.txt", path)

    def test_images_upload_to_path(self):
        path = images_upload_to(None, "test.txt")
        self.assertIn("images", path)
        self.assertIn("test.txt", path)

    def test_compare_data_with_dicts(self):
        dict1 = {"key1": "test", "key2": "test"}
        dict2 = {"key1": "test", "key2": "test"}
        self.assertTrue(compare_data(dict1, dict2, ["key1", "key2"]))
        dict1["key1"] = "test2"
        self.assertFalse(compare_data(dict1, dict2, ["key1", "key2"]))

    def test_compare_data_with_objects(self):
        object1 = type(str("test"), (object,), dict(key1="test", key2="test"))
        object2 = type(str("test"), (object,), dict(key1="test", key2="test"))
        self.assertTrue(compare_data(object1, object2, ["key1", "key2"]))
        object1.key1 = "test2"
        self.assertFalse(compare_data(object1, object2, ["key1", "key2"]))

    def test_compare_data_with_objects_as_attrs(self):
        obj = object()
        dict1 = {"key1": "test", "key2": obj}
        dict2 = {"key1": "test", "key2": obj}
        self.assertTrue(compare_data(dict1, dict2, ["key1", "key2"]))

    def test_compare_data_with_encoded_and_unicoded_str_as_attrs(self):
        dict1 = {"key1": "test", "key2": "test".encode("utf-8")}
        dict2 = {"key1": "test", "key2": "test"}
        self.assertTrue(compare_data(dict1, dict2, ["key1", "key2"]))

    def test_compare_data_with_special_characters(self):
        dict1 = {"key1": "test", "key2": "test é"}
        dict2 = {"key1": "test", "key2": "test é"}
        self.assertTrue(compare_data(dict1, dict2, ["key1", "key2"]))
