from smtplib import SMTPException
import logging

from django.conf import settings
from django.core.mail import get_connection

from celery import shared_task

from .utils import deserialize_email


logger = logging.getLogger('evote.maillings')


@shared_task(ignore_result=True)
def send_email(email_serialized):
    email = deserialize_email(email_serialized)
    connection = get_connection(backend=settings.CELERY_EMAIL_BACKEND)
    connection.open()
    try:
        email_sent = connection.send_messages([email])
        if not email_sent:
            logger.error("Failed sending email to: %r", email.to)
            return None
    except SMTPException:
        logger.exception("Failed sending email to: %r", email.to)
        return None
    connection.close()
    return email.to
