# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-17 17:41
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django_extensions.db.fields
import evotemailings.mixins
import evotemessages.managers


def assign_contacts(MessageContact, message):
    # response to anonymous user
    if message.sender_old_id and not message.recipients.exists():
        sender = MessageContact.objects.get_or_create_contact(
            message.sender_old, 'management')
        recipient = MessageContact.objects.get_or_create_contact(
            None, 'voters', email=message.anonymous_email)
    # sent by anonymous user
    elif not message.sender_old_id and message.recipients.exists():
        # ignore received messages, anonymous dont have inbox messages
        sender = MessageContact.objects.get_or_create_contact(
            None, 'voters', email=message.anonymous_email)
        if message.folder != 1:
            recipient = MessageContact.objects.get_or_create_contact(
                message.recipients.first(), 'management')
        else:
            recipient = None
    else:
        if message.subject.startswith('Re: '):
            sender = MessageContact.objects.get_or_create_contact(
                message.sender_old, 'management')
            recipient = MessageContact.objects.get_or_create_contact(
                message.recipients.first(), 'voters')
        else:
            sender = MessageContact.objects.get_or_create_contact(
                message.sender_old, 'voters')
            if message.folder != 1:
                recipient = MessageContact.objects.get_or_create_contact(
                    message.recipients.first(), 'management')
            else:
                recipient = None
    message.sender = sender
    message.recipient = recipient
    message.save()


def populate_messages(apps, schema_editor):
    Message = apps.get_model('evotemessages', 'Message')
    MessageContact = apps.get_model('evotemessages', 'MessageContact')
    for message in Message.objects.all():
        assign_contacts(MessageContact, message)


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('evotemessages', '0004_auto_20170124_1719'),
    ]

    operations = [
        migrations.CreateModel(
            name='MessageContact',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', django_extensions.db.fields.CreationDateTimeField(auto_now_add=True, verbose_name='created')),
                ('modified', django_extensions.db.fields.ModificationDateTimeField(auto_now=True, verbose_name='modified')),
                ('namespace', models.CharField(db_index=True, max_length=64)),
                ('name', models.CharField(max_length=128, null=True, verbose_name='name')),
                ('email', models.EmailField(max_length=128, null=True, verbose_name='email')),
                ('user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'message contact',
                'verbose_name_plural': 'message contacts',
            },
            bases=(evotemailings.mixins.MailingListMixin, models.Model),
            managers=[
                ('objects', evotemessages.managers.MessageContactManager()),
            ],
        ),
        migrations.RenameField(
            model_name='message',
            old_name='sender',
            new_name='sender_old'
        ),
        migrations.AddField(
            model_name='message',
            name='sender',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='sent', to='evotemessages.MessageContact', verbose_name='sender'),
        ),
        migrations.AddField(
            model_name='message',
            name='recipient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='evotemessages.MessageContact', verbose_name='recipient'),
        ),
        migrations.RunPython(populate_messages, reverse_code=migrations.RunPython.noop),
        migrations.RemoveField(
            model_name='message',
            name='sender_old'
        ),
        migrations.RemoveField(
            model_name='message',
            name='anonymous_email',
        ),
        migrations.RemoveField(
            model_name='message',
            name='recipients',
        ),
        migrations.RemoveField(
            model_name='message',
            name='slug',
        ),
        migrations.RemoveField(
            model_name='message',
            name='state'
        ),
        migrations.AlterField(
            model_name='message',
            name='body',
            field=models.TextField(verbose_name='body'),
        ),
        migrations.AlterField(
            model_name='message',
            name='folder',
            field=models.PositiveSmallIntegerField(choices=[(0, 'Received'), (1, 'Sent'), (2, 'Archived')], default=1, verbose_name='folder'),
        ),
        migrations.AlterField(
            model_name='message',
            name='parent',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='siblings', to='evotemessages.Message', verbose_name='parent message'),
        ),
        migrations.AlterField(
            model_name='message',
            name='read_at',
            field=models.DateTimeField(blank=True, null=True, verbose_name='read at'),
        ),
        migrations.AlterField(
            model_name='message',
            name='subject',
            field=models.CharField(max_length=260, verbose_name='subject'),
        ),
        migrations.AddField(
            model_name='message',
            name='recipient_uid',
            field=models.CharField(max_length=64, null=True, verbose_name='recipient uid'),
        ),
    ]
