from __future__ import unicode_literals

from mock import PropertyMock, patch

from django.test import SimpleTestCase

from evotemessages.mailings import MessageMail
from evotemessages.models import Message, MessageContact


class MessageMailTest(SimpleTestCase):
    """ """

    def test_get_subject(self):
        message = Message(subject="dummy title")
        mail = MessageMail(message)
        self.assertEqual(mail.get_subject(), "dummy title")

    def test_get_context_data(self):
        message = Message()
        mail = MessageMail(message)
        self.assertEqual({'message': message}, mail.get_context_data())

    @patch.object(MessageContact, 'is_anonymous', return_value=False,
                  new_callable=PropertyMock)
    def test_get_template_name(self, is_anonymous):
        message = Message(sender=MessageContact())
        mail = MessageMail(message)
        self.assertEqual(mail.get_template_name(),
                         "evotemessages/mails/message.html")

    @patch.object(MessageContact, 'is_anonymous', return_value=True,
                  new_callable=PropertyMock)
    def test_get_template_name_for_anonymous_sender(self, is_anonymous):
        message = Message(sender=MessageContact())
        mail = MessageMail(message)
        self.assertEqual(mail.get_template_name(),
                         "evotemessages/mails/message_anonymous.html")
