from __future__ import unicode_literals

from mock import patch

from django.utils import timezone
from django.test import SimpleTestCase

from evotemessages.models import Message


class MessageTest(SimpleTestCase):

    def test_str(self):
        message = Message(subject='dummy test')
        self.assertEqual(str(message), 'dummy test')

    def test_was_readed(self):
        message = Message()
        self.assertFalse(message.was_readed)
        message.read_at = timezone.now()
        self.assertTrue(message.was_readed)

    def test_is_archived(self):
        message = Message()
        self.assertFalse(message.is_archived)
        message.folder = Message.Folder.ARCHIVED
        self.assertTrue(message.is_archived)

    def test_is_sent(self):
        message = Message()
        self.assertTrue(message.is_sent)
        message.folder = Message.Folder.RECEIVED
        self.assertFalse(message.is_sent)

    def test_is_received(self):
        message = Message()
        self.assertFalse(message.is_received)
        message.folder = Message.Folder.RECEIVED
        self.assertTrue(message.is_received)

    @patch.object(Message, 'save')
    def test_mark_as_read(self, save):
        message = Message()
        message.mark_as_read()
        self.assertIsNotNone(message.read_at)
        save.assert_called_with(update_fields=['read_at'])

    @patch('evotemessages.models.send_to_recipients')
    def test_send_to_recipients(self, send_to_recipients):
        message = Message()
        message.send_to_recipients([1, 2])
        send_to_recipients.si.assert_called_with(None, [1, 2], True)

    @patch('evotemessages.models.send_to_recipients')
    def test_send_to_recipients_without_notify(self, send_to_recipients):
        message = Message()
        message.send_to_recipients([1, 2], False)
        send_to_recipients.si.assert_called_with(None, [1, 2], False)

    @patch('evotemessages.models.send_to_contacts')
    def test_send_to_contacts(self, send_to_contacts):
        message = Message()
        message.send_to_contacts([1, 2])
        send_to_contacts.si.assert_called_with(None, [1, 2], True)
