from __future__ import unicode_literals

from django.db.models import Q


class SearchableRegister(object):

    def __init__(self, model, title, content, extra=None):
        self.model = model
        self.title = title
        self.content = content
        self.extra = extra or {}

    def search(self, search_terms):
        results = []

        title_lookup = self.title + "__icontains"
        content_lookup = self.content + "__icontains"

        q = Q()
        for term in search_terms:
            title_arg = {title_lookup: term}
            content_arg = {content_lookup: term}

            q &= Q(**title_arg) | Q(**content_arg)

        qs = self.model._default_manager.filter(q, **self.extra)

        for result in qs:
            results.append({
                'title': getattr(result, self.title).encode('utf-8'),
                'content': getattr(result, self.content),
                'url': result.get_absolute_url()
            })

        return results


search_register = []
