from __future__ import unicode_literals

from django.core.management.base import BaseCommand
from django.core.validators import validate_email
from django.core.exceptions import ValidationError
from django.contrib.auth import get_user_model


class Command(BaseCommand):
    help = 'Used to define a user as admin.'

    def add_arguments(self, parser):
        parser.add_argument(
            'email', nargs='*', help='Specify the email of registered user.',
        )

    def handle(self, *args, **options):
        User = get_user_model()  # NOQA
        for email in options.get('email'):
            try:
                validate_email(email)
                user = User.objects.get(email=email)
            except ValidationError:
                self.print_error("Email malformed '{}'".format(email))
            except User.DoesNotExist:
                self.print_error("User with email '{}' does not exists"
                                 .format(email))
            else:
                user.set_as_admin()
                self.print_success("User with email '{}' setted as admin"
                                   .format(email))

    def print_success(self, msg):
        self.stdout.write(self.style.SUCCESS(msg))

    def print_error(self, msg):
        self.stderr.write(self.style.ERROR(msg))
