from __future__ import unicode_literals

from django.core.management.base import BaseCommand
from django.core.validators import validate_email
from django.core.exceptions import ValidationError

from evoteusers.models import User


class Command(BaseCommand):
    help = 'Used to define a user as institutional responsible.'

    def add_arguments(self, parser):
        parser.add_argument(
            'email', nargs=1, help='Specifies the email of registered user.',
        )

    def handle(self, *args, **options):
        email = options.get('email')[0]
        try:
            validate_email(email)
            user_responsibles = User.objects\
                .filter(is_institutional_responsible=True)\
                .exclude(email=email)
            user = User.objects.get(email=email)
        except ValidationError:
            self.print_error("Email malformed '{}'".format(email))
        except User.DoesNotExist:
            self.print_error("User with email '{}' does not exists yet"
                             .format(email))
        else:
            # remove prior responsibles permissions
            for user_responsible in user_responsibles:
                user_responsible.unset_as_institutional_responsible()
                self.print_info("Unsetted permissions for user: {}"
                                .format(user_responsible))
            # add permissions to new responsible
            user.set_as_institutional_responsible()
            self.print_success("Setted permissions for user: {}".format(user))

    def print_info(self, msg):
        self.stdout.write(self.style.NOTICE(msg))

    def print_success(self, msg):
        self.stdout.write(self.style.SUCCESS(msg))

    def print_error(self, msg):
        self.stderr.write(self.style.ERROR(msg))
