from __future__ import unicode_literals

import logging

from django.db import models


logger = logging.getLogger('evote.crypto')


class SecretEntryManager(models.Manager):
    """ """

    def check_integrity(self):
        """Checks if all entries are submitted"""
        valid = True
        identifier_list = [a for (a, b) in self.model.Identifier.choices]
        identifier_names = [b for (a, b) in self.model.Identifier.choices]
        entries = self.filter(identifier__in=identifier_list)\
            .only('identifier', 'body')
        if not entries.exists() or entries.count() != len(identifier_list):
            valid = False
        for entry in entries:
            if entry.body is None or entry.body == '':
                valid = False
                logger.error("Missing secret entry=%s",
                             identifier_names[entry.identifier])
        return valid
