from __future__ import unicode_literals

from django.utils.translation import ugettext_lazy as _
from django.utils.html import format_html
from django.core.urlresolvers import reverse_lazy

import django_tables2 as tables
from .models import Page


class PageTable(tables.Table):
    """
    Base Institutional Pages List table with common fields
    """

    title = tables.Column(attrs={'th': {'class': 's-15'}})
    created_by = tables.Column(
        attrs={'th': {'class': 's-20'}}
    )
    modified = tables.Column(attrs={'th': {'class': 's-15'}})

    class Meta:
        model = Page
        empty_text = _(u'No institutional pages exist.')
        orderable = False
        attrs = {
            "class": "pure-table pure-table-striped"
            " page-list"
        }
        fields = ('title', 'created_by', 'modified')

    def render_title(self, record):
        # [WIP] Title should link to page content (Still does not exist)
        url = reverse_lazy(
            'evoteadmin:page-update',
            kwargs={'slug': record.slug}
        )
        view_url = reverse_lazy(
            'evoteadmin:page-preview',
            kwargs={'slug': record.slug})

        return format_html(u"{}<br>"
                           '<span><a href="{}">{}</a> | '
                           '<a href="{}">{}</a></span>',
                           record.title, url, _(u'Edit'), view_url, _(u'View'))
