from __future__ import unicode_literals
from django import template
from evotevotings.admin.models import SecretEntry, Page


register = template.Library()

# This PK is associated with the fixture of pages (pages.json) and related to
# the page that stores the global messages
GLOBAL_ALERT_PAGE_PK = 10


@register.simple_tag
def certificate_identifier(value):
    """
        This tag receives an integer identifier and returns its counterpart
        string to the template
    """
    identifier = None

    if any(value in key for key in SecretEntry.Identifier.choices):
        identifier = SecretEntry.Identifier.choices[value][1]

    return identifier


@register.assignment_tag(takes_context=False)
def is_private_key(value):
    """
        This tag receives a certificate field identifier and returns
        a boolean depending on if that value is or not a private key
    """
    return any(value in key for key in SecretEntry.Identifier.private_keys)


@register.inclusion_tag('evoteadmin/includes/global_alert.html')
def global_alert():
    obj = Page.objects.filter(pk=GLOBAL_ALERT_PAGE_PK).first()
    if obj:
        return {'message': obj.body}
    return {'message': None}
