from unittest import skip

from django.core.urlresolvers import reverse
from django.test import SimpleTestCase
from . import AdminTestCase
from .utils import PageTestUtils, SecretEntryTestUtils
from evotevotings.admin.models import SecretEntry


class SecretEntryTest(SecretEntryTestUtils, SimpleTestCase):

    def test_str_equal_to_identifier(self):
        entry = SecretEntry(
            identifier=1,
            body=None
        )
        self.assertEqual(
            str(entry),
            entry.get_identifier_display()
        )

    def test_invalid_certificate(self):
        entry = SecretEntry(
            identifier=1,
            body=None
        )
        self.assertFalse(bool(entry.is_valid))


class PageTest(PageTestUtils, AdminTestCase):

    def setUp(self):
        self.credentials = {
            "email": "dev@eurotux.com",
            "password": "password"
        }
        self.user = self.create_user(is_staff=True, **self.credentials)
        self.instance = self.create_page(created_by=self.user)
        self.client.post(reverse('evoteadmin:login'), follow=True,
                         data=self.credentials)

    def test_str_equal_to_title(self):
        self.assertEqual(str(self.instance), self.instance.title)

    @skip("Trying to call an unregistered namespace for this app")
    def test_get_absolute_url(self):
        response = self.client.get(self.instance.get_absolute_url())
        self.assertEqual(response.status_code, 200)
