/* globals jQuery */

/******************************************************************
 * Site Name: eVote
 * Author: Sandro Rodrigues
 *
 * JavaScript: secure actions script
 *****************************************************************/

"use strict";

(function($) {

    $.fn.secureAction = function(options) {

        var opts = $.extend({
            flagWasValidatedAttr: "wasValidated",
        }, options);

        return this.each(function()
        {
            var $form = $(this);

            if ($form.attr('data-secure-action') !== '') {
                $form.data('needSecuredAction', true);

                $form.on("submit", function() {

                    var wasValidated = !! $form.data(opts.flagWasValidatedAttr);

                    if ( !wasValidated )
                    {
                        var modalOptions = {
                            remodal: {
                                hashTracking: false,
                                closeOnEscape: false,
                                closeOnOutsideClick: false
                            }
                        };

                        $.modalPartial( $form.data("secure-action"), modalOptions )
                            .done(function(modal)
                            {
                                var $innerForm = modal.find('form');

                                $innerForm.djangoAjaxForms({
                                    onSubmitSuccess: function()
                                    {
                                        modal.remodal().close();
                                        $form.data(opts.flagWasValidatedAttr, true);
                                        $form.trigger("submit");
                                    }
                                });
                            });
                    }

                    return wasValidated;
                });
            } else {
                return true;
            }
        });
    };

})(jQuery);
