from django.core.urlresolvers import reverse_lazy
from django.test import TestCase, override_settings, modify_settings

from evotevotings.processes.tests.utils import ProcessesTestUtils
from evotevotings.management.registers import secure_action
from evotevotings.management.forms import ManagementAuthenticationForm


@override_settings(
    ROOT_URLCONF='evote.urls.management',
    LOGIN_REDIRECT_URL=reverse_lazy("management:electoralprocess-list"),
    LOGIN_URL=reverse_lazy("management:login"),
    JAVASCRIPT_SETTINGS_SCAN_MODULES={},
    EVOTEMESSAGES_TEMPLATE_BASE_DIR='management/',
    EVOTEMESSAGES_BASE_APP_NAME='management'
)
@modify_settings(MIDDLEWARE={
    'append': 'evotevotings.management.middleware.ManagementMiddleware',
})
class ManagementTestCase(ProcessesTestUtils, TestCase):

    def login_as_member(self):
        credentials = {
            "email": "dev@eurotux.com",
            "password": "password"
        }
        self.member = self.create_electoral_member(**credentials)
        self.client.login(**credentials)
        self.set_as_member()
        return credentials

    def login_as_institutional(self):
        credentials = {
            "email": "dev_inst@eurotux.com",
            "password": "password",
            "role": 1
        }
        self.member = self.create_institutional_member(**credentials)
        self.client.login(**credentials)
        self.set_as_institutional()
        return credentials

    def set_as_institutional(self):
        session = self.client.session
        session['user_profile'] = \
            ManagementAuthenticationForm.Profiles.INSTITUTIONAL_RESPONSIBLE
        session.save()

    def set_as_member(self):
        session = self.client.session
        session['user_profile'] = \
            ManagementAuthenticationForm.Profiles.ELECTORAL_MEMBER
        session.save()

    def register_action(self, electoral_process_id, action):
        """ """
        key = secure_action.prefix_key(electoral_process_id)
        session = self.client.session
        session[key] = action
        session.save()
