from django.test import SimpleTestCase, RequestFactory
from django.views.generic import TemplateView

from evotevotings.management.mixins import HistoryMixin

from . import ManagementTestCase


class MixinsTestSimple(SimpleTestCase):

    class NokObject(HistoryMixin):
        """ """

    def test_mixin_nok(self):
        object = self.NokObject()
        self.assertRaises(NotImplementedError, object.get_electoral_process_pk)


class MixinsTest(ManagementTestCase):

    class DummyView(HistoryMixin, TemplateView):
        """ """
        process_pk = None

        def __init__(self, request, process_pk, *args, **kwargs):
            self.request = request
            self.process_pk = process_pk

        def get_electoral_process_pk(self):
            return self.process_pk

    def setUp(self):
        self.login_as_member()
        self.factory = RequestFactory()
        self.request = self.factory.get('/history/')
        setattr(self.member.user, 'is_electoral_member', True)
        self.request.user = self.member.user
        self.view = self.DummyView(
            self.request, self.member.electoral_process.pk)

    def test_context_data(self):
        kwargs = {}
        context = self.view.get_context_data(**kwargs)

        self.assertEqual(
            context['process_pk'], self.member.electoral_process.pk)
        self.assertEqual(context['next_page'], 1)
        self.assertEqual(context['show_history'], True)
        self.assertEqual(context['more'], True)
