from __future__ import unicode_literals

from mock import Mock

from evotevotings.management.registers import secure_action

from . import ManagementTestCase


class SecureActionSessionRegisterTest(ManagementTestCase):

    def setUp(self):
        self.mock = Mock()
        self.mock.session = {}

    def test_prefix_key(self):
        key = secure_action.prefix_key("test")
        self.assertEqual(
            key, "{}_{}".format(secure_action.SESSION_PREFIX, "test"))

    def test_register(self):
        key = secure_action.prefix_key(1)
        secure_action.register(self.mock, 1, "test")
        self.assertIn(key, self.mock.session)
        self.assertEqual(self.mock.session[key], "test")

    def test_reset(self):
        key = secure_action.prefix_key(1)
        secure_action.register(self.mock, 1, "test")
        secure_action.reset(self.mock, 1)
        self.assertNotIn(key, self.mock.session)

    def test_reset_unexistent_key(self):
        with self.assertRaises(KeyError):
            secure_action.reset(self.mock, 1)

    def test_validate_registered_action(self):
        key = secure_action.prefix_key(1)
        secure_action.register(self.mock, 1, "test")
        is_valid = secure_action.validate(self.mock, 1, "test")
        self.assertTrue(is_valid)
        self.assertNotIn(key, self.mock.session)

    def test_validate_unregistered_action(self):
        is_valid = secure_action.validate(self.mock, 1, "test")
        self.assertFalse(is_valid)
