from __future__ import unicode_literals

import logging

from django.apps import apps

from django_fsm import can_proceed
from celery import shared_task


logger = logging.getLogger('evote.core')


def get_electoral_process(pk):
    ElectoralProcess = apps.get_model('evoteprocesses.ElectoralProcess')  # noqa
    return ElectoralProcess.objects.get(pk=pk)


@shared_task(ignore_result=True)
def publish_electoral_process(electoral_process_id):
    """ """
    electoral_process = get_electoral_process(electoral_process_id)
    if can_proceed(electoral_process.publish):
        old_state = electoral_process.get_state_display()
        electoral_process.publish()
        electoral_process.save()
        logger.info("Electoral_process=%d: changed status='%s' => status='%s'",
                    electoral_process.pk, old_state,
                    electoral_process.get_state_display())
    else:
        logger.warning("Electoral_process=%d: can't change to status='Open'",
                       electoral_process.pk)
    return electoral_process


@shared_task(ignore_result=True)
def close_electoral_process(electoral_process_id):
    """ """
    electoral_process = get_electoral_process(electoral_process_id)
    if can_proceed(electoral_process.close):
        old_state = electoral_process.get_state_display()
        electoral_process.close()
        electoral_process.save()
        logger.info("Electoral_process=%d: changed status='%s' => status='%s'",
                    electoral_process.pk, old_state,
                    electoral_process.get_state_display())
    else:
        logger.warning("Electoral_process=%d: can't change to status='Closed'",
                       electoral_process.pk)
    return electoral_process


@shared_task(ignore_result=True)
def archive_electoral_process(electoral_process_id):
    """ """
    electoral_process = get_electoral_process(electoral_process_id)
    if can_proceed(electoral_process.archive):
        old_state = electoral_process.get_state_display()
        electoral_process.archive()
        electoral_process.save()
        logger.info("Electoral_process=%d: changed status='%s' => status='%s'",
                    electoral_process.pk, old_state,
                    electoral_process.get_state_display())
    else:
        logger.warning(
            "Electoral_process=%d: can't change to status='Archived'",
            electoral_process.pk)
    return electoral_process
