from django.test import TestCase
from django.utils import timezone
from django.db.models.functions import Now

from evotevotings.processes.models import ElectoralProcess

from evotevotings.processes.tests.utils import ProcessesTestUtils
from evoteusers.tests.utils import UserTestUtils


class ElectoralProcessManagerTest(ProcessesTestUtils, UserTestUtils, TestCase):
    """
    Test Managers of Electoral Process
    """

    def test_published(self):

        self.create_electoral_process(publication_date=timezone.now())
        self.create_electoral_process(publication_date=timezone.now())
        self.create_electoral_process(
            publication_date=timezone.now(), state=ElectoralProcess.State.OPEN)

        valid_qs = ElectoralProcess.objects.filter(
            publication_date__lte=Now(),
            state=ElectoralProcess.State.OPEN)
        published = ElectoralProcess.objects.published()

        self.assertQuerysetEqual(valid_qs, map(repr, published))

    def test_open(self):
        self.create_electoral_process(state=ElectoralProcess.State.OPEN)
        self.create_electoral_process(state=ElectoralProcess.State.NEW)

        valid_qs = ElectoralProcess.objects.filter(
            state=ElectoralProcess.State.OPEN)
        open_qs = ElectoralProcess.objects.open()

        self.assertQuerysetEqual(valid_qs, map(repr, open_qs))
