from __future__ import unicode_literals

from django.core.management.base import BaseCommand
from django.contrib.auth import get_user_model


from evotevotings.voters.models import ElectionVoter
from evotevotings.elections.models import Election
from evotevotings.processes.models import ElectoralProcess
from evotevotings.services.routers import ASrouter
from evotelogs.registers import audit_register


class Command(BaseCommand):
    help = 'Cleanup election generated to swarm votes'
    # Class variables
    # self.election : Election created to simulate the votes

    def add_arguments(self, parser):
        parser.add_argument(
            'election_id', nargs='?', help='Election ID to cleanup',
        )

    def handle(self, child=None, *args, **options):
        audit_register.remove(ElectionVoter)
        audit_register.remove(get_user_model())
        # Get the election ID to cleanup
        election_id = int(options.get('election_id'))
        try:
            election = Election.objects.get(pk=election_id)
            electoral_process = ElectoralProcess.objects.get(
                pk=election.electoral_process.pk
            )
        except Exception:
            self.print_error("No election to cleanup.\n")
            return False

        # Cleanup
        mail_suffix = "simulate_%d.vote.org" % election_id
        ElectionVoter.objects.filter(
            election_id=election.pk,
            name=mail_suffix
        ).delete()
        get_user_model().objects.filter(
            email__contains=mail_suffix,
        ).delete()
        election.categories.all().delete()
        election.delete()
        electoral_process.delete()
        ASrouter().close_election(election_id)
        self.print_success("Cleanup complete\n")

    def print_success(self, msg):
        self.stdout.write(self.style.SUCCESS(msg))

    def print_error(self, msg):
        self.stderr.write(self.style.ERROR(msg))
