from __future__ import unicode_literals

from django.utils.translation import ugettext_lazy as _
from django.db.models import Q

from evotemessages.decorators import recipients
from evotemessages.recipients import BaseRecipientsGroup

from .models import ElectionVoter


@recipients
class ElectionVoterRecipientsGroup(BaseRecipientsGroup):
    """ """
    model = ElectionVoter
    prefix = _('Election voter:')
    namespace = "voters"

    def search(self, query, group_object_id, **kwargs):
        if not group_object_id:  # if no group provided, return empty
            return self.model.objects.none()
        return self.get_queryset()\
            .select_related('user', 'election')\
            .filter(Q(name__icontains=query) |
                    Q(personnel_number__icontains=query) |
                    Q(user__email__icontains=query) |
                    Q(user__notice_email__icontains=query),
                    election__electoral_process_id=group_object_id)\
            .order_by()

    def get_user_ids(self, obj):
        if obj:
            return [obj.user_id]
        return []

    def get_group_object(self, obj):
        return obj.election.electoral_process

    def get_unique_id(self, obj):
        return obj.user_id

    def check_permission(self, user):
        return getattr(user, 'is_electoral_member', False)
