from __future__ import unicode_literals

from django import template

from evotevotings.elections.models import Candidate


register = template.Library()


@register.inclusion_tag('voters/includes/candidate_list.html')
def candidate_list(candidates_list, **kwargs):
    """ """
    candidates = []
    for candidate in candidates_list:
        candidates.append((candidate_obj(candidate.choice_value), candidate))
    return {
        'candidate_list': candidates,
    }


@register.inclusion_tag('voters/includes/candidate_dropdown.html')
def candidate_dropdown(candidates_list, **kwargs):
    """ """
    candidates = []
    extra_attrs = []
    if candidates_list.field.required:
        extra_attrs.append('required')
    if candidates_list.field.disabled:
        extra_attrs.append('disabled')

    for candidate in candidates_list.field.choices:
        if candidate[0]:
            candidates.append((candidate_obj(candidate[0]), candidate[1]))
        else:
            candidates.append(('', candidate[1]))
    return {
        'candidate_list_attr': candidates_list,
        'candidate_list': candidates,
        'extra_attrs': ' '.join(extra_attrs)
    }


@register.simple_tag
def candidate_obj(candidate_id):
    """ """
    return Candidate.objects.get(pk=candidate_id)


@register.simple_tag
def election_closed_for_voter(user_id, election):
    """ Return False if the election is not closed and the user did not
        submit his vote. """
    if not election.is_in_to_vote:
        return True
    election_voter = election.election_voters.filter(user=user_id).first()
    return not bool(election_voter and election_voter.can_vote())
