from django.core.urlresolvers import reverse
from django.test import TestCase

from mock import patch

from evotevotings.elections.tests.utils import ElectionsTestUtils
from evoteusers.tests.utils import UserTestUtils


class VoteReferencesAjaxViewTest(UserTestUtils, ElectionsTestUtils, TestCase):

    def setUp(self):
        self.login()
        self.election = self.create_election()
        self.references = ["REF1", "REF2", ]
        self.url = reverse("voters:vote-reference-next-page", kwargs={
            "pk": self.election.electoral_process_id,
            "pk_election": self.election.pk
        })

    def test_login_required(self):
        """ """
        self.client.logout()
        response = self.client.get(self.url)
        self.assertEqual(response.status_code, 302)

    @patch("evotevotings.voters.ajax.get_references", return_value=([], False))
    def test_used_template(self, mock_fn):
        """ """
        response = self.client.get(self.url)
        self.assertEqual(response.status_code, 200)
        self.assertTemplateUsed(
            response, 'voters/includes/vote_reference_list.html')

    @patch("evotevotings.voters.ajax.get_references")
    def test_fetch_references(self, mock_fn):
        """ """
        mock_fn.return_value = (self.references, False)
        response = self.client.get(self.url)
        context = response.context
        self.assertIn("references", context)

    @patch("evotevotings.voters.ajax.get_references")
    def test_paginated_references(self, mock_fn):
        """ """
        mock_fn.return_value = (self.references, True)
        response = self.client.get(self.url)
        context = response.context
        self.assertIn("next_page", context)
        self.assertIn("more", context)
        self.assertTrue(context['more'])
