from __future__ import unicode_literals

from django.test import TestCase
from django.core.urlresolvers import reverse
from django.template.defaultfilters import truncatechars

from evotevotings.elections.tests.utils import ElectionsTestUtils
from evotevotings.processes.models import ElectoralProcess
from evotevotings.voters.tables import ElectoralProcessArchiveTable


class ElectoralProcessArchiveTableTest(ElectionsTestUtils, TestCase):
    """
    Test custom fields output of Archive table
    """
    def setUp(self):
        self.table = ElectoralProcessArchiveTable({})

    def test_render_elections_valid(self):
        election = self.create_election()
        base_url = reverse(
            "voters:electoralprocess-detail",
            args=[election.electoral_process.slug]
        )
        url = base_url + "#election-" + str(election.pk)
        expected = "<ul><li><a href='{}'>{}</a></li></ul>"\
            .format(url, truncatechars(election.identifier, 20))
        rendered = self.table.render_elections(election.electoral_process)
        self.assertInHTML(expected, rendered)

    def test_render_elections_empty_valid(self):
        process = ElectoralProcess()
        expected = "<ul><li>No Elections</li></ul>"
        rendered = self.table.render_elections(process)
        self.assertInHTML(expected, rendered)
