# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from mock import Mock

from django.template import Context, Template
from django.test import TestCase

from evotevotings.elections.tests.utils import ElectionsTestUtils


class TemplateTagsTest(object):

    def render_template(self, string, context=None, request=None):
        context = context or {}
        context = Context(context)
        return Template(string).render(context)


class VotersTagsTest(TemplateTagsTest, ElectionsTestUtils, TestCase):
    """ """

    def create_candidate_list_field(self, choices=[]):
        """ """
        candidate_list = Mock()
        candidate_list.attrs.id = 'testid'
        candidate_list.attrs.name = 'testname'
        candidate_list.field.disabled = True
        candidate_list.field.required = True
        candidate_list.field.choices = choices
        candidate_list.auto_id = 1
        candidate_list.name = 'test'
        return candidate_list

    def test_candidate_list_no_candidates(self):
        """ """
        context = {'candidates': []}
        template = "{% load voters_tags %}{% candidate_list candidates %}"
        expected = ""
        rendered = self.render_template(template, context)
        self.assertInHTML(expected, rendered)

    def test_candidate_list_with_candidates(self):
        """ """
        candidate = self.create_candidate(**{'logo': None,
                                             'designation': 'test'})
        candidate_list = self.create_candidate_list_field()
        candidate_list.choice_value = candidate.id
        context = {'candidates': [candidate_list]}
        template = "{% load voters_tags %}{% candidate_list candidates %}"
        expected = (
            '<div data-vote-option class="candidate-box">'
            '    <img data-candidate-logo class="candidate-logo" '
            'src="/static/images/avatar.png" width="85" height="85" '
            'alt="candidate">'
            '    <div class="candidate-designation">'
            '        <p data-candidate-designation>test</p>'
            '    </div>'
            '    <label for="testid" class="pure-checkbox">'
            '        <input data-vote-checkbox id="testid" name="test" '
            'value="1" type="checkbox">'
            '        <span></span>'
            '    </label>'
            '</div>'
        )
        rendered = self.render_template(template, context)
        self.assertInHTML(expected, rendered)

    def test_candidate_dropdown(self):
        """ """
        candidate_list = self.create_candidate_list_field()
        context = {'candidates': candidate_list}
        template = "{% load voters_tags %}{% candidate_dropdown candidates %}"
        expected = (
            '<div class="candidate-box">'
            '    <img data-candidate-logo class="candidate-logo" '
            'src="/static/images/avatar.png" width="85" height="85" '
            'alt="candidate">'
            '    <div class="candidate-designation">'
            '        <select data-select-vote data-style-select id="1" '
            'name="test" class="pure-select" required disabled>'
            '        </select>'
            '    </div>'
            '    <label for="field" class="pure-checkbox no-selectable">'
            '        <input data-vote-simulation name="vote" value="" '
            'type="checkbox">'
            '        <span></span>'
            '    </label>'
            '</div>'
        )
        rendered = self.render_template(template, context)
        self.assertInHTML(expected, rendered)

    def test_candidate_dropdown_with_candidates(self):
        """ """
        candidate = self.create_candidate(**{'logo': None})
        choices = [(candidate.id, 'label')]
        candidate_list = self.create_candidate_list_field(choices)
        context = {'candidates': candidate_list}
        template = "{% load voters_tags %}{% candidate_dropdown candidates %}"
        expected = (
            '<div class="candidate-box">'
            '    <img data-candidate-logo class="candidate-logo" '
            'src="/static/images/avatar.png" width="85" height="85" '
            'alt="candidate">'
            '    <div class="candidate-designation">'
            '        <select data-select-vote data-style-select id="1" '
            'name="test" class="pure-select" required disabled>'
            '            <option data-logo="/static/images/avatar.png" '
            'value="1">label</option>'
            '        </select>'
            '    </div>'
            '    <label for="field" class="pure-checkbox no-selectable">'
            '        <input data-vote-simulation name="vote" value="" '
            'type="checkbox">'
            '        <span></span>'
            '    </label>'
            '</div>'
        )
        rendered = self.render_template(template, context)
        self.assertInHTML(expected, rendered)

    def test_candidate_dropdown_with_candidate_not_found_in_db(self):
        """ """
        choices = [(None, 'label')]
        candidate_list = self.create_candidate_list_field(choices)
        context = {'candidates': candidate_list}
        template = "{% load voters_tags %}{% candidate_dropdown candidates %}"
        expected = (
            '<div class="candidate-box">'
            '    <img data-candidate-logo class="candidate-logo" '
            'src="/static/images/avatar.png" width="85" height="85" '
            'alt="candidate">'
            '    <div class="candidate-designation">'
            '        <select data-select-vote data-style-select id="1" '
            'name="test" class="pure-select" required disabled>'
            '            <option data-logo="/static/images/avatar.png" '
            'value="">label</option>            '
            '        </select>'
            '    </div>'
            '    <label for="field" class="pure-checkbox no-selectable">'
            '        <input data-vote-simulation name="vote" value="" '
            'type="checkbox">'
            '        <span></span>'
            '    </label>'
            '</div>'
        )
        rendered = self.render_template(template, context)
        self.assertInHTML(expected, rendered)
